diff treepkg/packager.py @ 517:de78084fcbce

rename do_svn_update in do_update because we provide svn and git support now
author Bjoern Ricks <bricks@intevation.de>
date Wed, 10 Nov 2010 13:17:32 +0000
parents e5698096f1ec
children 9c8e2c05c775
line wrap: on
line diff
--- a/treepkg/packager.py	Wed Nov 10 12:03:58 2010 +0000
+++ b/treepkg/packager.py	Wed Nov 10 13:17:32 2010 +0000
@@ -689,14 +689,14 @@
     def packager_for_new_revision(self):
         return self.new_revsision_packager()
 
-    def package_if_updated(self, revision=None, do_svn_update=True):
+    def package_if_updated(self, revision=None, do_update=True):
         """Returns a new packager if the working copy has not been packaged yet.
         If do_svn_update is true -- the default -- update the working
         copy to the revision specified with the revision parameter
         or if revision is None, the latest revision in the repository."""
         if not self.do_build:
             return None
-        if do_svn_update:
+        if do_update:
             self.update_checkout(revision=revision)
             # TODO: what should happen with the debian checkout, if a
             # revision for the source checkoute was given?
@@ -769,13 +769,13 @@
 class PackagerGroup(object):
 
     def __init__(self, package_tracks, check_interval, revision=None,
-                 instructions_file=None, do_svn_update=True,
+                 instructions_file=None, do_update=True,
                  stop_on_error=False, name="", treepkg_dir=None, 
                  tracks_dir=None):
         self.package_tracks = package_tracks
         self.check_interval = check_interval
         self.revision = revision
-        self.do_svn_update = do_svn_update
+        self.do_update = do_update
         self.stop_on_error = stop_on_error
         self.instructions_file = instructions_file
         self.instructions_file_removed = False
@@ -856,7 +856,7 @@
             for track in self.package_tracks:
                 try:
                     packager = track.package_if_updated(revision=self.revision,
-                                              do_svn_update=self.do_svn_update)
+                                              do_update=self.do_update)
                     if packager:
                         packager.package()
                         repeat = self.install_dependencies(track, packager)
@@ -689,14 +689,14 @@
         """Returns a new packager if the working copy has not been packaged yet.
-        If do_svn_update is true -- the default -- update the working
+        If do_update is true -- the default -- update the working
         copy to the revision specified with the revision parameter
         or if revision is None, the latest revision in the repository."""
This site is hosted by Intevation GmbH (Datenschutzerklärung und Impressum | Privacy Policy and Imprint)